import 'package:flutter/material.dart';

class AnimatedGraphCursorPainter extends CustomPainter {
  final Animation<double> animation;
  final Color cursorColor;
  final double opacity;
  final double radius;

  AnimatedGraphCursorPainter({
    required this.animation,
    this.cursorColor = Colors.white,
    this.opacity = 0.25,
    this.radius = 16,
  }) : super(repaint: animation);

  @override
  void paint(Canvas canvas, Size size) {
    _paintCursor(canvas, size);
  }

  @override
  bool shouldRepaint(CustomPainter oldDelegate) => true;

  void _paintCursor(Canvas canvas, Size size) {
    final animationPercent = animation.value;
    final x = size.width * 0.815;
    final y = size.height * 0.45;
    final center = Offset(x, y);
    final paint = Paint();

    paint.color = cursorColor.withOpacity(opacity);
    canvas.drawCircle(center, radius * animationPercent, paint);
  }
}
